# @craftworks/eslint-config-angular

[![NPM version](https://img.shields.io/npm/v/@craftworks/eslint-config-angular.svg?style=flat)](https://www.npmjs.com/package/@craftworks/eslint-config-angular)
[![Downloads](http://img.shields.io/npm/dm/@craftworks/eslint-config-angular.svg?style=flat)](https://npmjs.org/package/@craftworks/eslint-config-angular)

An ESLint config optimized for Angular.

Contains the configs of

- \*\*/\*.ts
  - [@craftworks/eslint-config-typescript](https://github.com/craftworksgmbh/craftworks-frontend-libraries/tree/master/packages/craftworks-eslint-config-typescript)
    - [eslint:recommended](https://eslint.org/docs/latest/rules/)
    - [@typescript-eslint/recommended-type-checked](https://typescript-eslint.io/rules/)
    - [@typescript-eslint/strict-type-checked](https://typescript-eslint.io/rules/)
    - [@typescript-eslint/stylistic-type-checked](https://typescript-eslint.io/rules/)
    - [unicorn/recommended](https://github.com/sindresorhus/eslint-plugin-unicorn#rules)
    - [jsdoc/recommended-typescript](https://github.com/gajus/eslint-plugin-jsdoc#rules)
  - [@angular-eslint/recommended](https://github.com/angular-eslint/angular-eslint/tree/main/packages/eslint-plugin)
  - [jest/recommended](https://github.com/jest-community/eslint-plugin-jest#rules)
  - [jest/style](https://github.com/jest-community/eslint-plugin-jest#rules)
  - [rxjs/recommended](https://github.com/cartant/eslint-plugin-rxjs#rules)
  - [compat/recommended](https://github.com/amilajack/eslint-plugin-compat)
  - [prettier](https://github.com/prettier/prettier-eslint)
- \*\*/\*.html
  - [@angular-eslint/template/recommended](https://github.com/angular-eslint/angular-eslint/tree/main/packages/eslint-plugin-template)
  - [@angular-eslint/template/accessibility](https://github.com/angular-eslint/angular-eslint/tree/main/packages/eslint-plugin-template)
  - [prettier](https://github.com/prettier/prettier-eslint)

and applies a custom [config](src/index.ts).

Following configurations are provided

- [@craftworks/eslint-config-angular](src/index.ts)
- [@craftworks/eslint-config-angular/unsafe-typing](src/index.unsafe-typing.ts) Use on top of @craftworks/eslint-config-angular; disables rules regarding `!` and `any` which may be convenient for the developer if disabled, although they come with some degree of type safety reduction.
- [@craftworks/eslint-config-angular/tslint-config-angular-bridge](src/index.tslint-config-angular-bridge.ts) Use on top of @craftworks/eslint-config-angular and [@craftworks/eslint-config-angular/unsafe-typing; allows easier migration by disabling a set of rules if you are coming from @craftworks/tslint-config-angular. It is recommended to avoid this config in the long run, as it won't be actively maintained.
- [@craftworks/eslint-config-angular/speed-up](src/index.speed-up.ts) Use on top of @craftworks/eslint-config-angular; disables some of the rules that run for relatively too long compared to the value they provide.

Note that this setup is not set up for \*\*/\*.js files.

## Installation

```sh
npm install @craftworks/eslint-config-angular --save-dev
```

Check for necessary [peer dependencies](#peer-dependencies).

## Usage

`eslint.config.mjs`

```js
import eslintConfigAngular from '@craftworks/eslint-config-angular';

export default [
  ...eslintConfigAngular,
  {
    files: ['**/*.ts'],
    languageOptions: {
      parserOptions: {
        project: ['./tsconfig.lint.json'],
      },
    },
    rules: {
      '@angular-eslint/component-selector': [
        'error',
        {
          type: ['element', 'attribute'],
          prefix: '[PREFIX]',
          style: 'kebab-case',
        },
      ],
      '@angular-eslint/directive-selector': [
        'error',
        {
          type: ['element', 'attribute'],
          prefix: '[PREFIX]',
          style: 'camelCase',
        },
      ],
      // Optional TypeScript rule overwrites
    },
  },
  {
    files: ['**/*.html'],
    rules: {
      // Optional HTML rule overwrites
    },
  },
];
```

Create a `tsconfig.lint.json` for your Angular project that defines all the files that should be linted.

```json
{
  "extends": "./tsconfig.json",
  "include": ["src"]
}
```

Note that only [flat config](https://eslint.org/docs/latest/use/configure/configuration-files) is supported.

### Migration from `@craftworks/tslint-config-angular`

Allows easier migration by disabling a set of rules that would make migration more difficult.
It is recommended to avoid this config in the long run, as it won't be actively maintained.

`eslint.config.mjs`

```js
import eslintConfigAngular from '@craftworks/eslint-config-angular';
import eslintConfigAngularUnsafeTyping from '@craftworks/eslint-config-angular/unsafe-typing';
import eslintConfigAngularTslintConfigAngularBridge from '@craftworks/eslint-config-angular/tslint-config-angular-bridge';

export default [
  ...eslintConfigAngular,
  ...eslintConfigAngularUnsafeTyping,
  ...eslintConfigAngularTslintConfigAngularBridge,
  {
    files: ['**/*.ts'],
    languageOptions: {
      parserOptions: {
        project: ['./tsconfig.lint.json'],
      },
    },
    rules: {
      // Optional TypeScript rule overwrites
    },
  },
  {
    files: ['**/*.html'],
    rules: {
      // Optional HTML rule overwrites
    },
  },
];
```

## Peer Dependencies

- `eslint: ^9.0.0`
- `angular-eslint: >=18.0.0`
- `@eslint/js: ^9.0.0`
- `typescript: ^4.8.4 || ^5.0.0`
- `typescript-eslint: ^8.0.0`

The version of `angular-eslint` must match the version of Angular you are using.

The minimal node version is `18.18.0`.

See [package.json](package.json) for more details

## Change Log

See [CHANGELOG.md](CHANGELOG.md)

## License

[MIT](LICENSE)
