import base from './index.base.js';
const config = [
    ...base,
    {
        files: ['**/*.ts'],
        rules: {
            // @craftworks/eslint-config-typescript
            //////
            // Allow empty constructors
            // methods due to ngOnInit() { ... }
            '@typescript-eslint/no-empty-function': ['error', { allow: ['constructors', 'arrowFunctions', 'methods'] }],
            '@typescript-eslint/no-useless-constructor': 'off',
            // Disable unbound-method check
            // Reason: Angular works with pattern, e.g. Validators.required
            '@typescript-eslint/unbound-method': 'off',
            // @angular-eslint
            //////
            // Allow empty lifecycle method
            // Reason: Due to empty ngOnInit() { ... }
            '@angular-eslint/no-empty-lifecycle-method': 'off',
            // Prefer to declare @Output as readonly since they are not supposed to be reassigned
            '@angular-eslint/prefer-output-readonly': 'error',
            // Check component and directive selectors
            // It's advised to overrule these in the project while adding a project-specific 'prefix'!
            '@angular-eslint/component-selector': [
                'error',
                {
                    type: ['element', 'attribute'],
                    style: 'kebab-case',
                },
            ],
            '@angular-eslint/directive-selector': [
                'error',
                {
                    type: ['element', 'attribute'],
                    style: 'camelCase',
                },
            ],
            // Turn conflicting lifecycle checks off
            // Reason: very rare use-case, and it could result in false positives https://github.com/angular-eslint/angular-eslint/issues/502
            '@angular-eslint/no-conflicting-lifecycle': 'off',
            // rxjs
            //////
            // Enforces the use of Finnish notation
            'rxjs/finnish': 'error',
            // Enforces the passing of Error values to error notifications
            'rxjs/throw-error': 'error',
            // Allow passing methods that are not bound
            'rxjs/no-unbound-methods': 'off',
            // Buggy
            'rxjs/no-implicit-any-catch': 'off',
            // jest
            //////
            // Allow tests that use "expect" within "if" blocks
            'jest/no-conditional-expect': 'off',
            // unicorn
            //////
            // Don't prefer top-level await over top-level promises and async function calls
            // Reason: The bootstrap code of Angular that is provided for new projects doesn't use it, therefore no reason to enforce it
            'unicorn/prefer-top-level-await': 'off',
            // Don't prefer globalThis
            // Reason: Angular is in a browser environment therefore we don't need to ensure cross-environment safety
            'unicorn/prefer-global-this': 'off',
        },
    },
    {
        files: ['**/*.html'],
        rules: {
            // @angular-eslint/template
            //////
            // Disallow usage of $any
            // This rule is disabled via unsafe-typing
            '@angular-eslint/template/no-any': 'error',
            // Enforce usage of self-closing-tag
            '@angular-eslint/template/prefer-self-closing-tags': 'error',
            // Enforce attributes order
            '@angular-eslint/template/attributes-order': 'error',
        },
    },
];
export default config;
