// Disables a set of rules to allow easier migration if you are coming from @craftworks/tslint-config-angular
const config = [
    {
        files: ['**/*.ts'],
        rules: {
            // eslint
            //////
            // Allow declarations (let, const, function, class) within switch-case blocks
            'no-case-declarations': 'off',
            // Allow Object.prototype calls, e.g. foo.hasOwnProperty(...)
            'no-prototype-builtins': 'off',
            // Allow empty blocks
            'no-empty': 'off',
            // @typescript-eslint
            //////
            // Allow empty functions and interfaces
            '@typescript-eslint/no-empty-function': 'off',
            '@typescript-eslint/no-empty-interface': 'off',
            // Allow using "!" at optional chains, e.g. foo?.bar!;
            '@typescript-eslint/no-non-null-asserted-optional-chain': 'off',
            // Allow unhandled Promise-like statements
            '@typescript-eslint/no-floating-promises': 'off',
            // Allow "@ts-ignore" (even if "@ts-expect-error" would be better)
            '@typescript-eslint/ban-ts-comment': 'off',
            // Use "readonly" instead of "get", e.g. public readonly shouldLabelFloat = true; instead of public get ... return true
            '@typescript-eslint/class-literal-property-style': 'off',
            // Allow redundant unions, e.g. (string | 'fit') or (never | null)
            '@typescript-eslint/no-redundant-type-constituents': 'off',
            // Don't prefer using "??" over "||"
            '@typescript-eslint/prefer-nullish-coalescing': 'off',
            // Don't prefer using "?." instead of "&&"
            '@typescript-eslint/prefer-optional-chain': 'off',
            // Doesn't matter whether "const map: Map<string, number> = new Map();" or "const map = new Map<string, number>();"
            '@typescript-eslint/consistent-generic-constructors': 'off',
            // It's OK to state inferrable types, e.g. public isLoading: boolean = false;
            '@typescript-eslint/no-inferrable-types': 'off',
            // Don't require await
            '@typescript-eslint/require-await': 'off',
            // Don't fix confusing void expressions
            '@typescript-eslint/no-confusing-void-expression': 'off',
            // The naming convention rules didn't work as expected in @craftworks/tslint-config-angular
            // therefore it is defined very relaxed in the bridge as we do not know if the codebase followed the naming schema or not
            '@typescript-eslint/naming-convention': [
                'error',
                // Group selectors
                {
                    selector: 'default',
                    format: ['camelCase', 'PascalCase', 'UPPER_CASE', 'snake_case'],
                    leadingUnderscore: 'allowSingleOrDouble',
                    trailingUnderscore: 'allowSingleOrDouble',
                },
                // Ignore properties that require quotes
                {
                    selector: [
                        'classProperty',
                        'objectLiteralProperty',
                        'typeProperty',
                        'classMethod',
                        'objectLiteralMethod',
                        'typeMethod',
                        'accessor',
                        'enumMember',
                    ],
                    format: null,
                    modifiers: ['requiresQuotes'],
                },
            ],
            // Instead of using the Record datatype, allow expressions like interface Foo { [key: string]: unknown; }
            '@typescript-eslint/consistent-indexed-object-style': 'off',
            // Don't enforce dot notation, e.g. ARTICLE_SINGULAR['female'] --> ARTICLE_SINGULAR.female
            '@typescript-eslint/dot-notation': 'off',
            // Don't enforce removing of unnecessary conditions
            '@typescript-eslint/no-unnecessary-condition': 'off',
            // Allow for-in-loops for array
            '@typescript-eslint/no-for-in-array': 'off',
            // Allow to add number with a string (e.g. "foo" + 123)
            '@typescript-eslint/restrict-plus-operands': ['error', { allowNumberAndString: true }],
            // @angular-eslint
            //////
            // Allow @Output() bindings to be named as standard DOM events
            '@angular-eslint/no-output-native': 'off',
            // Allow empty lifecycle method
            '@angular-eslint/no-empty-lifecycle-method': 'off',
            // Allow renaming the @Input() and @Output()
            '@angular-eslint/no-input-rename': 'off',
            '@angular-eslint/no-output-rename': 'off',
            // Don't prefer to declare @Output as readonly
            '@angular-eslint/prefer-output-readonly': 'off',
            // Don't check component and directive selectors
            '@angular-eslint/component-selector': 'off',
            '@angular-eslint/directive-selector': 'off',
            // rxjs
            //////
            // Allow using ReplaySubject, publishReplay or shareReplay without specifying the buffer size
            'rxjs/no-ignored-replay-buffer': 'off',
            // Allow simple shareReplay
            'rxjs/no-sharereplay': 'off',
            // unicorn
            //////
            // 1.) Rules without auto fixers
            // Defines how files should be named
            'unicorn/filename-case': 'off',
            // Allow any eslint-disable comment
            'unicorn/no-abusive-eslint-disable': 'off',
            // 2.) Rules with auto fixers, but it's better if they are not fixed due its different style compared to @craftworks/tslint-config-angular
            // Don't prefer using logical operators over ternary expressions
            'unicorn/prefer-logical-operator-over-ternary': 'off',
            // Don't prefer to switch over multiple else-if
            'unicorn/prefer-switch': 'off',
            // Don't prefer JavaScript modules (ESM) over CommonJS.
            'unicorn/prefer-module': 'off',
            // Don't prefer using .at() for index access of arrays
            'unicorn/prefer-at': 'off',
            // Don't prefer .some(…) over .filter(…).length check and .{find,findLast}(…)
            'unicorn/prefer-array-some': 'off',
            // Don't prefer String#replaceAll() over regex searches with the global flag, e.g. str.replace(new RegExp(`(${find})`, 'gi'), '<strong>$1</strong>');
            'unicorn/prefer-string-replace-all': 'off',
            // Don't prefer Number static properties over global ones, e.g. "Infinity" vs. Number.POSITIVE_INFINITY
            'unicorn/prefer-number-properties': 'off',
            // Don't prefer Node#append()/Node#remove() over Node#appendChild()/Node#removeChild().
            'unicorn/prefer-dom-node-append': 'off',
            'unicorn/prefer-dom-node-remove': 'off',
            // Don't prefer the spread operator over Array.from(…), Array#concat(…), Array#{slice,toSpliced}() and String#split('')
            'unicorn/prefer-spread': 'off',
            // Don't prefer indexOf over findIndex
            'unicorn/prefer-array-index-of': 'off',
            // Don't prefer for…of over the forEach method
            'unicorn/no-array-for-each': 'off',
            // Allow useless switch default statements
            'unicorn/no-useless-switch-case': 'off',
            // Allow "new Array();"
            'unicorn/no-new-array': 'off',
            // Do not prefer Math.min / Math.max
            'unicorn/prefer-math-min-max': 'off',
            // Don't enforce the style of numeric separators by correctly grouping digits, e.g. 1234555.06 -> 1_234_555.06
            'unicorn/numeric-separators-style': 'off',
            // Don't enforce a specific parameter naming convention in catch clauses, e.g. err --> error
            'unicorn/catch-error-name': 'off',
            // Don't prefer Array.flat() over legacy techniques to flatter arrays
            'unicorn/prefer-array-flat': 'off',
            // Allow warning comments such as
            // TODO: some comment
            // FIXME: some comment
            // XXX: some comment
            'unicorn/expiring-todo-comments': [
                'error',
                {
                    allowWarningComments: true,
                },
            ],
        },
    },
    {
        files: ['**/*.html'],
        rules: {
            // @angular-eslint/template
            //////
            // Don't enforce self-closing-tags
            '@angular-eslint/template/prefer-self-closing-tags': 'off',
            // Don't enforce attributes order
            '@angular-eslint/template/attributes-order': 'off',
            // Disable allow accessibility rules
            '@angular-eslint/template/alt-text': 'off',
            '@angular-eslint/template/click-events-have-key-events': 'off',
            '@angular-eslint/template/elements-content': 'off',
            '@angular-eslint/template/interactive-supports-focus': 'off',
            '@angular-eslint/template/label-has-associated-control': 'off',
            '@angular-eslint/template/mouse-events-have-key-events': 'off',
            '@angular-eslint/template/no-autofocus': 'off',
            '@angular-eslint/template/no-distracting-elements': 'off',
            '@angular-eslint/template/role-has-required-aria': 'off',
            '@angular-eslint/template/table-scope': 'off',
            '@angular-eslint/template/valid-aria': 'off',
        },
    },
];
export default config;
